@@ -39,13 +39,7 @@ use simplelog::SimpleLogger;
 fn main() {
     let _ = SimpleLogger::init(LevelFilter::Info, Config::default());
 
-    let matches = app_from_crate!()
-        .arg(
-            Arg::with_name("config-file")
-                .help("Path to config file")
-                .required(true),
-        )
-        .get_matches();
+    let matches = build_app().get_matches();
 
     let config = matches.value_of("config-file").unwrap();
 
@@ -54,3 +48,21 @@ fn main() {
         process::exit(1);
     }
 }
+
+fn build_app() -> App<'static> {
+    app_from_crate!().arg(
+        Arg::new("config-file")
+            .help("Path to config file")
+            .required(true),
+    )
+}
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    #[test]
+    fn verify_app() {
+        build_app().debug_assert();
+    }
+}
